==> sbcli_max-14.0.56.tar.gz: sbcli_max-14.0.56/setup.py <==
import os
import subprocess
from pathlib import Path

from setuptools import setup, find_packages

from setuptools.command.install import install as _install
from setuptools.command.build_py import build_py


def _post_install():
    from subprocess import getstatusoutput
    _, out = getstatusoutput('activate-global-python-argcomplete --user')
    print(out)

    if os.environ.get("SHELL") and os.environ.get("HOME"):
        if "zsh" in os.environ.get("SHELL", ""):
            path = f"{os.environ.get('HOME')}/.zshenv"
        else:
            path = f"{os.environ.get('HOME')}/.bash_completion"
        if os.path.isfile(path):
            _, out = getstatusoutput(f'source {path}')


class install(_install):
    def run(self):
        _install.run(self)
        self.execute(_post_install, (), msg="Running post install task")


class GenerateCLICommand(build_py):
    def get_source_files(self) -> list[str]:
        return ['scripts/cli-wrapper-gen.py', 'scripts/cli-wrapper.jinja2'] + super().get_source_files()

    def get_outputs(self) -> list[str]:
        return ['simplyblock_cli/cli.py'] + super().get_outputs()

    def run(self):
        super().run()
        subprocess.check_call(['python3', Path('scripts/cli-wrapper-gen.py').absolute(), Path('.').absolute()])
        self.copy_file('simplyblock_cli/cli.py', Path(self.build_lib, 'simplyblock_cli'))


def get_env_var(name, default=None):
    if not name:
        return False
    with open("simplyblock_core/env_var", "r", encoding="utf-8") as fh:
        lines = fh.readlines()
    data = {}
    for line in lines:
        if not line or line.startswith("#"):
            continue
        try:
            k, v = line.split("=")
            data[k.strip()] = v.strip()
        except:
            pass
    return data.get(name, default)


def gen_data_files(*dirs):
    results = []
    for src_dir in dirs:
        files = [f for f in os.listdir(src_dir) if os.path.isfile(f"{src_dir}/{f}") and f != ".DS_Store"]
        if not files:
            return []
        results.append((src_dir, [f"{src_dir}/{f}" for f in files]))
        dirs = [f for f in os.listdir(src_dir) if os.path.isdir(f"{src_dir}/{f}")]
        for dir in dirs:
            results.extend(gen_data_files(os.path.join(src_dir, dir)))
    return results


def get_long_description():
    with open("README.md", "r", encoding="utf-8") as fh:
        return fh.read()


def get_requirements():
    with open("requirements.txt", "r", encoding="utf-8") as fh:
        return fh.readlines()


COMMAND_NAME = get_env_var("SIMPLY_BLOCK_COMMAND_NAME", "sbcli")
VERSION = get_env_var("SIMPLY_BLOCK_VERSION", "1")

data_files = gen_data_files("simplyblock_core","simplyblock_web")
data_files.append(('', ["requirements.txt"]))
# data_files.append(('/etc/simplyblock', ["requirements.txt"]))


setup(
    name=COMMAND_NAME,
    version=VERSION,
    packages=find_packages(exclude=["e2e*"]),
    url='https://www.simplyblock.io/',
    author='Hamdy',
    author_email='hamdy@simplyblock.io',
    description='CLI for managing SimplyBlock cluster',
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    install_requires=get_requirements(),
    entry_points={
        'console_scripts': [
            f'{COMMAND_NAME}=simplyblock_cli.cli:main',
        ]
    },
    include_package_data=True,
    data_files=data_files,
    package_data={
        '': ["/etc/simplyblock/requirements.txt"],
        '/etc/simplyblock': ["requirements.txt"]
    },
    cmdclass={
        'install': install,
        'build_py': GenerateCLICommand,
    },
)

==> sbcli_max-14.0.57.tar.gz: sbcli_max-14.0.57/setup.py <==
import os
import subprocess
from pathlib import Path

from setuptools import setup, find_packages

from setuptools.command.install import install as _install
from setuptools.command.build_py import build_py


def _post_install():
    from subprocess import getstatusoutput
    _, out = getstatusoutput('activate-global-python-argcomplete --user')
    print(out)

    if os.environ.get("SHELL") and os.environ.get("HOME"):
        if "zsh" in os.environ.get("SHELL", ""):
            path = f"{os.environ.get('HOME')}/.zshenv"
        else:
            path = f"{os.environ.get('HOME')}/.bash_completion"
        if os.path.isfile(path):
            _, out = getstatusoutput(f'source {path}')


class install(_install):
    def run(self):
        _install.run(self)
        self.execute(_post_install, (), msg="Running post install task")


class GenerateCLICommand(build_py):
    def get_source_files(self) -> list[str]:
        return ['cli-reference.yaml', 'scripts/cli-wrapper-gen.py', 'scripts/cli-wrapper.jinja2'] + super().get_source_files()

    def get_outputs(self) -> list[str]:
        return ['simplyblock_cli/cli.py'] + super().get_outputs()

    def run(self):
        super().run()
        subprocess.check_call(['python3', Path('scripts/cli-wrapper-gen.py').absolute(), Path('.').absolute()])
        self.copy_file('simplyblock_cli/cli.py', Path(self.build_lib, 'simplyblock_cli'))


def get_env_var(name, default=None):
    if not name:
        return False
    with open("simplyblock_core/env_var", "r", encoding="utf-8") as fh:
        lines = fh.readlines()
    data = {}
    for line in lines:
        if not line or line.startswith("#"):
            continue
        try:
            k, v = line.split("=")
            data[k.strip()] = v.strip()
        except:
            pass
    return data.get(name, default)


def gen_data_files(*dirs):
    results = []
    for src_dir in dirs:
        files = [f for f in os.listdir(src_dir) if os.path.isfile(f"{src_dir}/{f}") and f != ".DS_Store"]
        if not files:
            return []
        results.append((src_dir, [f"{src_dir}/{f}" for f in files]))
        dirs = [f for f in os.listdir(src_dir) if os.path.isdir(f"{src_dir}/{f}")]
        for dir in dirs:
            results.extend(gen_data_files(os.path.join(src_dir, dir)))
    return results


def get_long_description():
    with open("README.md", "r", encoding="utf-8") as fh:
        return fh.read()


def get_requirements():
    with open("requirements.txt", "r", encoding="utf-8") as fh:
        return fh.readlines()


COMMAND_NAME = get_env_var("SIMPLY_BLOCK_COMMAND_NAME", "sbcli")
VERSION = get_env_var("SIMPLY_BLOCK_VERSION", "1")

data_files = gen_data_files("simplyblock_core","simplyblock_web")
data_files.append(('', ["requirements.txt"]))
# data_files.append(('/etc/simplyblock', ["requirements.txt"]))


setup(
    name=COMMAND_NAME,
    version=VERSION,
    packages=find_packages(exclude=["e2e*"]),
    url='https://www.simplyblock.io/',
    author='Hamdy',
    author_email='hamdy@simplyblock.io',
    description='CLI for managing SimplyBlock cluster',
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    install_requires=get_requirements(),
    entry_points={
        'console_scripts': [
            f'{COMMAND_NAME}=simplyblock_cli.cli:main',
        ]
    },
    include_package_data=True,
    data_files=data_files,
    package_data={
        '': ["/etc/simplyblock/requirements.txt"],
        '/etc/simplyblock': ["requirements.txt"]
    },
    cmdclass={
        'install': install,
        'build_py': GenerateCLICommand,
    },
)
